@@ -45,7 +45,7 @@ public:
     int m_maxNumClosedItems;
 };
 
-Q_GLOBAL_STATIC(KonqClosedWindowsManagerPrivate, myKonqClosedWindowsManagerPrivate)
+static KonqClosedWindowsManagerPrivate *myKonqClosedWindowsManagerPrivate = nullptr;
 
 KonqClosedWindowsManager::KonqClosedWindowsManager()
 {
@@ -88,9 +88,18 @@ KConfig *KonqClosedWindowsManager::memoryStore()
 
 KonqClosedWindowsManager *KonqClosedWindowsManager::self()
 {
+    if (!myKonqClosedWindowsManagerPrivate) {
+        myKonqClosedWindowsManagerPrivate = new KonqClosedWindowsManagerPrivate;
+    }
     return &myKonqClosedWindowsManagerPrivate->instance;
 }
 
+void KonqClosedWindowsManager::destroy()
+{
+    delete myKonqClosedWindowsManagerPrivate;
+    myKonqClosedWindowsManagerPrivate = nullptr;
+}
+
 void KonqClosedWindowsManager::addClosedWindowItem(KonqUndoManager
         *real_sender, KonqClosedWindowItem *closedWindowItem, bool propagate)
 {
@@ -213,7 +222,7 @@ void KonqClosedWindowsManager::slotNotifyClosedWindowItem(
 
     // Create a new ClosedWindowItem and add it to the list
     KonqClosedWindowItem *closedWindowItem = new KonqClosedRemoteWindowItem(
-        title, configGroup, configFileName,
+        title, memoryStore(), configGroup, configFileName,
         KIO::FileUndoManager::self()->newCommandSerialNumber(), numTabs,
         service);
 
@@ -415,7 +424,7 @@ void KonqClosedWindowsManager ::readConfig()
         int numTabs = configGroup.readEntry("numTabs", 0);
 
         KonqClosedWindowItem *closedWindowItem = new KonqClosedWindowItem(
-            title,  i, numTabs);
+            title, memoryStore(), i, numTabs);
         configGroup.copyTo(&closedWindowItem->configGroup());
         configGroup.writeEntry("foo", 0);
 
