@@ -23,6 +23,7 @@
 #define KTABWIDGET_H
 
 #include <QTabWidget>
+#include <konqprivate_export.h>
 
 class QTab;
 
@@ -33,7 +34,7 @@ class QTab;
  *
  * See also the QTabWidget documentation.
  */
-class KTabWidget : public QTabWidget
+class KONQ_TESTS_EXPORT KTabWidget : public QTabWidget
 {
     Q_OBJECT
     Q_PROPERTY(bool automaticResizeTabs READ automaticResizeTabs WRITE setAutomaticResizeTabs)
@@ -141,12 +142,6 @@ Q_SIGNALS:
      */
     void mouseMiddleClick(QWidget *);
 
-    /**
-     * The close button of a widget's tab was clicked. This signal is
-     * only possible after you have called setCloseButtonEnabled( true ).
-     */
-    void closeRequest(QWidget *);
-
 protected:
     void mouseDoubleClickEvent(QMouseEvent *) override;
     void mousePressEvent(QMouseEvent *) override;
@@ -167,7 +162,6 @@ protected Q_SLOTS:
     virtual void contextMenu(int, const QPoint &);
     virtual void mouseDoubleClick(int);
     virtual void mouseMiddleClick(int);
-    virtual void closeRequest(int);
 #ifndef QT_NO_WHEELEVENT
     virtual void wheelDelta(int);
 #endif
